==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property days Number of days that you want to specify for the default retention period.
 * @property mode Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
 * @property years Number of years that you want to specify for the default retention period.
 */
public data class BucketObjectLockConfigurationV2RuleDefaultRetentionArgs(
    public val days: Output<Int>? = null,
    public val mode: Output<String>? = null,
    public val years: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs> {
    override fun toJava():
        com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs =
        com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.builder()
            .days(days?.applyValue({ args0 -> args0 }))
            .mode(mode?.applyValue({ args0 -> args0 }))
            .years(years?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketObjectLockConfigurationV2RuleDefaultRetentionArgs].
 */
@PulumiTagMarker
public class BucketObjectLockConfigurationV2RuleDefaultRetentionArgsBuilder internal constructor() {
    private var days: Output<Int>? = null

    private var mode: Output<String>? = null

    private var years: Output<Int>? = null

    /**
     * @param value Number of days that you want to specify for the default retention period.
     */
    @JvmName("dgdhecuseslejuks")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
     */
    @JvmName("ceclwqshjnfyfvak")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value Number of years that you want to specify for the default retention period.
     */
    @JvmName("psrvhmcbsejveugd")
    public suspend fun years(`value`: Output<Int>) {
        this.years = value
    }

    /**
     * @param value Number of days that you want to specify for the default retention period.
     */
    @JvmName("xnfdsusvhksmwqqv")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
     */
    @JvmName("wncfcrbvbjkplmpt")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Number of years that you want to specify for the default retention period.
     */
    @JvmName("hvcvqajqhkelnxyf")
    public suspend fun years(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.years = mapped
    }

    internal fun build(): BucketObjectLockConfigurationV2RuleDefaultRetentionArgs =
        BucketObjectLockConfigurationV2RuleDefaultRetentionArgs(
            days = days,
            mode = mode,
            years = years,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/s3/kotlin/inputs/BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.s3.kotlin.inputs

import com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 *
 * @property days Number of days that you want to specify for the default retention period.
 * @property mode Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
 * @property years Number of years that you want to specify for the default retention period.
 */
public data class BucketObjectLockConfigurationV2RuleDefaultRetentionArgs(
    public val days: Output<Int>? = null,
    public val mode: Output<String>? = null,
    public val years: Output<Int>? = null,
) :
    ConvertibleToJava<com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs> {
    override fun toJava(): com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs =
        com.pulumi.aws.s3.inputs.BucketObjectLockConfigurationV2RuleDefaultRetentionArgs.builder()
            .days(days?.applyValue({ args0 -> args0 }))
            .mode(mode?.applyValue({ args0 -> args0 }))
            .years(years?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [BucketObjectLockConfigurationV2RuleDefaultRetentionArgs].
 */
@PulumiTagMarker
public class BucketObjectLockConfigurationV2RuleDefaultRetentionArgsBuilder internal constructor() {
    private var days: Output<Int>? = null

    private var mode: Output<String>? = null

    private var years: Output<Int>? = null

    /**
     * @param value Number of days that you want to specify for the default retention period.
     */
    @JvmName("ekxugtqviyeyecji")
    public suspend fun days(`value`: Output<Int>) {
        this.days = value
    }

    /**
     * @param value Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
     */
    @JvmName("alijxtsfdqngdjvp")
    public suspend fun mode(`value`: Output<String>) {
        this.mode = value
    }

    /**
     * @param value Number of years that you want to specify for the default retention period.
     */
    @JvmName("ocrtrgixmmcbtuvp")
    public suspend fun years(`value`: Output<Int>) {
        this.years = value
    }

    /**
     * @param value Number of days that you want to specify for the default retention period.
     */
    @JvmName("gshfqucpqruaubin")
    public suspend fun days(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.days = mapped
    }

    /**
     * @param value Default Object Lock retention mode you want to apply to new objects placed in the specified bucket. Valid values: `COMPLIANCE`, `GOVERNANCE`.
     */
    @JvmName("vkwjmtxkldkhtclp")
    public suspend fun mode(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.mode = mapped
    }

    /**
     * @param value Number of years that you want to specify for the default retention period.
     */
    @JvmName("hydmbfifsflnpjkr")
    public suspend fun years(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.years = mapped
    }

    internal fun build(): BucketObjectLockConfigurationV2RuleDefaultRetentionArgs =
        BucketObjectLockConfigurationV2RuleDefaultRetentionArgs(
            days = days,
            mode = mode,
            years = years,
        )
}
